@@ -467,7 +467,13 @@ ORBit_POA_handle_request(GIOPRecvBuffer *recv_buffer,
 	g_assert(poa);
 	g_assert(servant);
 
-	skel = ORBIT_OBJECT_KEY(servant->_private)->class_info->relay_call(servant, recv_buffer, &imp);
+	if(recv_buffer->message.u.request.operation[0] == '_') {
+		guchar *opname = recv_buffer->message.u.request.operation;
+
+		if(!strcmp(opname, "_is_a"))
+			skel = &ORBit_impl_CORBA_Object_is_a;
+	} else
+		skel = ORBIT_OBJECT_KEY(servant->_private)->class_info->relay_call(servant, recv_buffer, &imp);
 
 	if(!skel) {
 		CORBA_exception_set_system(&ev, ex_CORBA_BAD_OPERATION,
